
# energie_gv_at
This module retrieves data from energie.gv.at.

The reading current_hour_status is above 1 when you should try to save energy.

# Usage
```
define energy_austria fhempy energie_gv_at
```
